@@ -37,7 +37,7 @@ class Eloverblik:
                                     {parsed_from_date}/{parsed_to_date}/{aggregation}',
                                  data=body,
                                  headers=headers,
-                                 timeout=10
+                                 timeout=5
                                  )
 
         raw_response = RawResponse()
@@ -50,7 +50,7 @@ class Eloverblik:
         url = self._base_url + 'api/Token'
         headers = {'Authorization': 'Bearer ' + self._refresh_token}
 
-        token_response = requests.get(url, headers=headers)
+        token_response = requests.get(url, headers=headers, timeout=5)
         token_response.raise_for_status()
 
         token_json = token_response.json()
@@ -85,7 +85,9 @@ class Eloverblik:
         '''
         Get latest data. Will look for one week. 
         '''
-        raw_data = self.get_time_series(metering_point, from_date=datetime.now()-timedelta(days=8))
+        raw_data = self.get_time_series(metering_point, 
+                                        from_date=datetime.now()-timedelta(days=8), 
+                                        to_date=datetime.now())
 
         if raw_data.status == 200:
             json_response = json.loads(raw_data.body)
@@ -107,6 +109,7 @@ class Eloverblik:
         '''
         Parse result from API call.
         '''
+        print(result)
         parsed_result = {}
 
         if 'result' in result and len(result['result']) > 0:
